pub type FastSet1<V> = HashSet<V, BuildHasherDefault<FxHasher>>;Expand description
A fast set that is not resistant to collision attacks. Works on one byte at a time.
Aliased Type
pub struct FastSet1<V> { /* private fields */ }pub type FastSet1<V> = HashSet<V, BuildHasherDefault<FxHasher>>;A fast set that is not resistant to collision attacks. Works on one byte at a time.
pub struct FastSet1<V> { /* private fields */ }